<?php

declare(strict_types=1);

use app\models\Product;
use app\models\Search;

?>

<link href="/css/pages/search.css" rel="stylesheet">

<div id="page_search" class="container flex-grow-1 d-flex">
    <?php

    if (isset($timer) && $timer > 0) : ?>

        <div class="row py-3 w-100">
            <section class="col">
                <div class="d-flex flex-column mx-auto">
                    <p class="px-2 mb-1 text-center d-flex justify-content-center">Слишком частые запросы, повторите попытку через: <?= $timer ?? 5 ?> секунд</p>
                    <small class="mb-3 text-center d-flex justify-content-center">Подождите или нажмите на кнопку вручную</small>
                    <a class="btn text-white button_clean button_blue mx-auto" title="Перезагрузить страницу" role="button" onclick="window.location.reload();">Повторить</a>
                </div>
                <script type="text/javascript">
                    setTimeout('window.location.reload()', <?= $timer ?? 5 ?> + '000');
                </script>

            <?php else : ?>
                <?php if (isset($response) && is_array($response) && $response) : ?>

                    <div class="row py-4 w-100 flex-column">
                        <section class="col-auto mb-4">
                            <h4 class="ml-4 mb-3">Товары по запросу: "<?= $query ?? 'ошибка чтения запроса' ?>"</h4>

                            <?php foreach ($response as $row) : ?>
                                <?php
                                // Инициализация данных товара
                                $cpny = $covr = $catg = $catn = null;

                                // Инициализация реестра пустышек (товаров без поставок или с ошибками)
                                $empties = [];

                                // Генерация списка товаров
                                $supplies_html = Search::generate($row, $cpny, $covr, $catg, $catn, $empties);

                                extract($row);
                                ?>
                                <div class="col mb-2">
                                    <div class="row p-2 rounded">
                                        <img class="ml-0 h-100 img-fluid rounded" src="<?= $covr ?>" />
                                        <div class="col-3 ml-3 p-0 d-flex flex-column row_fixed_height">
                                            <a class="my-auto text-dark" href="/product/<?= $catn ?>">
                                                <h5 class="m-0"><?= $cpny ?></h5>
                                                <h6 class="m-0"><small><?= $catn ?></small></h6>
                                            </a>
                                        </div>
                                        <!-- <div class="col-1 ml-2 p-0 d-flex flex-column row_fixed_height">
                                            <a class="my-auto text-dark" href="/product/<?= $catn ?>">
                                                <small><?= $catg ?></small>
                                            </a>
                                        </div> -->
                                        <div class="col ml-3 p-0 d-flex flex-column">
                                            <?= $supplies_html ?>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach ?>
                        </section>

                        <?php if (!empty($empties)) : ?>
                            <section class="col">
                                <?php foreach ($empties as $catn) : ?>

                                    <?php if ($products = Search::content(products: Product::searchAnalogs($catn))) : ?>

                                        <h4 class="ml-4 mb-3">Аналогичные товары</h4>

                                        <?php foreach ($products as $product) : ?>
                                            <?php
                                            // Инициализация данных товара
                                            $cpny = $covr = $catg = $catn = null;

                                            // Генерация списка товаров
                                            $supplies_html = Search::generate($product, $cpny, $covr, $catg, $catn);

                                            extract($product);
                                            ?>
                                            <div class="col mb-2">
                                                <div class="row p-2 rounded">
                                                    <img class="ml-0 h-100 img-fluid rounded" src="<?= $covr ?>" />
                                                    <div class="col-3 ml-3 p-0 d-flex flex-column row_fixed_height">
                                                        <a class="my-auto text-dark" href="/product/<?= $catn ?>">
                                                            <h5 class="m-0"><?= $cpny ?></h5>
                                                            <h6 class="m-0"><small><?= $catn ?></small></h6>
                                                        </a>
                                                    </div>
                                                    <!-- <div class="col-1 ml-2 p-0 d-flex flex-column row_fixed_height">
                                                    <a class="my-auto text-dark" href="/product/<?= $catn ?>">
                                                        <small><?= $catg ?></small>
                                                    </a>
                                                </div> -->
                                                    <div class="col ml-3 p-0 d-flex flex-column">
                                                        <?= $supplies_html ?>
                                                    </div>
                                                </div>
                                            </div>
                                        <?php endforeach ?>

                                    <?php endif ?>

                                <?php endforeach ?>
                            </section>
                        <?php endif ?>
                    </div>

                <?php else : ?>
                    <?php if ($advanced ?? false) : ?>

                        <h1 class="m-auto gilroy text-center"><b>Ничего не найдено</b></h1>

                    <?php else : ?>

                        <div class="row py-3 w-100">
                            <section class="col">
                                <div class="d-flex flex-column mx-auto">
                                    <p class="m-0 py-2 d-flex justify-content-center">Ничего не найдено</p>
                                </div>
                            </section>
                        </div>

                    <?php endif ?>
                <?php endif ?>

            </section>
        </div>

    <?php endif ?>

</div>

<script src="/js/cart.js" defer></script>
<script src="/js/product.js" defer></script>
<?php if (
    !yii::$app->user->isGuest
    && (yii::$app->user->identity->type === 'administrator'
        || yii::$app->user->identity->type === 'moderator')
) : ?>
    <script src="/js/product_panel.js" defer></script>
<?php endif ?>
